@@ -15,6 +15,7 @@
 #   Author: David Moreau Simard <moi@dmsimard.com>
 #
 
+
 class FunctionNotImplemented(Exception):
     """
     Function not yet finished
@@ -28,11 +29,19 @@ class UnsupportedRequestType(Exception):
     If a requested body type is not mapped
     """
     def __str__(self):
-        return "Unknown request type. Requests available: 'json', 'xml', 'text'."
+        return "Unknown request type."
+
 
 class UnsupportedBodyType(Exception):
     """
     If a requested body type is not mapped
     """
     def __str__(self):
-        return "This type of body is not supported for this API call."
\ No newline at end of file
+        return "This type of body is not supported for this API call."
+
+class UnsupportedArgument(Exception):
+    """
+    If attempting to use an unsupported argument
+    """
+    def __str__(self):
+        return "This function does not currently support this argument."
\ No newline at end of file
